@@ -1,14 +1,11 @@
 import numpy as np
+import Deep_Learning_Framework.utils
 import copy
 from math import sqrt
 from itertools import product
-from Deep_Learning_Framework import *
 
 
 # Base class for Layers
-from Deep_Learning_Framework import utils
-
-
 class Layer:
     def __init__(self):
         """
