@@ -1,9 +1,9 @@
 import numpy as np
 import math
-from layer import *
-from losses import *
-from activations import *
-from loss import *
+import Deep_Learning_Framework.layer
+
+import Deep_Learning_Framework.loss
+import Deep_Learning_Framework.activations
 
 
 def change_to_vector(y):
